@@ -21,6 +21,9 @@
 #include <launcher/launcher.h>
 
 void test_icon_utils_create_suite (void);
+void test_launcher_create_suite (void);
+
+void test_category_create_suite (void);
 
 gint
 main (gint argc, gchar *argv[])
@@ -32,6 +35,8 @@ main (gint argc, gchar *argv[])
 
   /* Please keep this alphabetically ordered */
   test_icon_utils_create_suite ();
+  test_launcher_create_suite ();
+  test_category_create_suite ();
 
   return g_test_run ();
 }
